/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1


Rectangle {
    anchors {
        margins: units.gu(1.5)
    }
    border.color: "#AAA"
    border.width: units.gu(.1)
    color: "transparent"
    height: textColumn.childrenRect.height
    width: units.gu(10)

    property alias text: pauseLabel.text
    property alias time: timeTimer.time

    MouseArea {
        anchors {
            fill: parent
        }

        onClicked: pauseOverlay.pause()
    }

    Column {
        id: textColumn
        anchors {
            fill: parent
        }

        Label {
            id: timeLabel
            anchors {
                horizontalCenter: parent.horizontalCenter
            }
            text: timeToString(timeTimer.time)

            function timeToString(time) {
                var minutes = Math.floor(time / 60);
                var seconds = Math.floor(time % 60);

                if (minutes.toString() == "NaN") {
                    minutes = 0
                }
                if (seconds.toString() == "NaN") {
                    seconds = 0
                }

                return minutes + ":" + (seconds < 10 ? "0" + seconds : seconds);
            }

            Timer {
                id: timeTimer
                repeat: true
                interval: 1000
                running: gameScene.running
                onTriggered: time++

                property int time: 0
            }
        }

        Label {
            id: pauseLabel
            anchors {
                horizontalCenter: parent.horizontalCenter
            }
            objectName: "pauseLabel"
            text: i18n.tr("Pause")
        }
    }
}
