/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1
import Bacon2D 1.0
import "../scenes"

Page {
    state: width > height ? "landscape" : "portrait"
    states: [
        State {
            name: "portrait"
            PropertyChanges {
                target: game
                currentScene: rotateScreenScene
            }
            PropertyChanges {
                target: gameScene
                running: false
            }
        },
        State {
            name: "landscape"
            PropertyChanges {
                target: game
                currentScene: game.actualScene
            }
        }
    ]

    Game {
        id: game
        height: parent.height
        width: parent.width

        property Scene actualScene: menuScene

        MenuScene {
            id: menuScene
            objectName: "menuScene"
            onStartGame: {
                game.actualScene = gameScene
                gameScene.restart()
            }
        }

        FinishScene {
            id: finishScene
            objectName: "finishScene"
            onFinishedComplete: game.actualScene = menuScene
        }

        GameScene {
            id: gameScene
            objectName: "gameScene"

            onGameFinished: {
                // Tell finish scene about the scores
                finishScene.computerScore = computer.score
                finishScene.humanScore = human.score

                // Save new time if it is faster
                if (human.score > computer.score &&
                        (gameHeader.time < settings.highScore || settings.highScore === -1)) {
                    settings.highScore = gameHeader.time
                    finishScene.newHighScore = true
                } else {
                    finishScene.newHighScore = false
                }

                // Switch to the finish scene
                game.actualScene = finishScene;
            }
        }

        RotateScreenScene {
            id: rotateScreenScene
            objectName: "rotateScreenScene"
        }
    }
}
