/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import Bacon2D 1.0
import Ubuntu.Components 1.1
import QtQuick 2.3


Scene {
    height: parent.height
    physics: false
    running: false
    viewport: Viewport {
    }
    width: parent.width

    signal startGame()

    MouseArea {
        id: readyMouseArea
        anchors {
            fill: parent
        }
        onClicked: startGame()

        Rectangle {
            anchors {
                fill: parent
            }
            color: "#000"
            opacity: .2
        }

        Column {
            anchors {
                centerIn: parent
            }
            spacing: units.gu(1)

            Label {
                anchors {
                    horizontalCenter: parent.horizontalCenter
                }
                fontSize: "x-large"
                objectName: "mainLabel"
                text: i18n.tr("Volleyball")
            }

            Label {
                anchors {
                    horizontalCenter: parent.horizontalCenter
                }
                fontSize: "large"
                objectName: "subLabel"
                text: i18n.tr("Tap to play")
            }

            Label {
                anchors {
                    horizontalCenter: parent.horizontalCenter
                }
                horizontalAlignment: Text.AlignHCenter
                fontSize: "small"
                objectName: "instructionLabel"
                text: settings.useMotion ?
                          i18n.tr("Rotate your device to move your player") + "\n"
                          + i18n.tr("Tap to jump")
                        :
                          i18n.tr("Press on the left or right of the screen to move") + "\n"
                          + i18n.tr("Tap in the center or a two finger press to jump")
            }

            Label {
                anchors {
                    horizontalCenter: parent.horizontalCenter
                }
                horizontalAlignment: Text.AlignHCenter
                fontSize: "small"
                text: i18n.tr("Fastest time") + ": " + settings.highScore
                visible: settings.highScore > -1
            }
        }

        Button {
            anchors {
                bottom: parent.bottom
                bottomMargin: units.gu(2)
                right: parent.right
                rightMargin: units.gu(2)
            }
            iconName: "settings"
            objectName: "settingsButton"
            width: height
            onClicked: mainPageStack.push(settingsPage)
        }
    }
}
